| Safe Haskell | None |
|---|---|
| Language | Haskell98 |
Lava.Generic
Documentation
transStruct :: Struct [a] -> [Struct a] Source
Instances
| Generic () Source | |
| Generic Symbol Source | |
| Generic a => Generic [a] Source | |
| Generic (Signal a) Source | |
| (Generic a, Generic b) => Generic (a, b) Source | |
| (Generic a, Generic b, Generic c) => Generic (a, b, c) Source | |
| (Generic a, Generic b, Generic c, Generic d) => Generic (a, b, c, d) Source | |
| (Generic a, Generic b, Generic c, Generic d, Generic e) => Generic (a, b, c, d, e) Source | |
| (Generic a, Generic b, Generic c, Generic d, Generic e, Generic f) => Generic (a, b, c, d, e, f) Source | |
| (Generic a, Generic b, Generic c, Generic d, Generic e, Generic f, Generic g) => Generic (a, b, c, d, e, f, g) Source |
pickSymbol :: Generic a => String -> a -> Symbol Source
class Generic a => Constructive a where Source
Instances
| Constructive () Source | |
| ConstructiveSig a => Constructive (Signal a) Source | |
| (Constructive a, Constructive b) => Constructive (a, b) Source | |
| (Constructive a, Constructive b, Constructive c) => Constructive (a, b, c) Source | |
| (Constructive a, Constructive b, Constructive c, Constructive d) => Constructive (a, b, c, d) Source | |
| (Constructive a, Constructive b, Constructive c, Constructive d, Constructive e) => Constructive (a, b, c, d, e) Source | |
| (Constructive a, Constructive b, Constructive c, Constructive d, Constructive e, Constructive f) => Constructive (a, b, c, d, e, f) Source | |
| (Constructive a, Constructive b, Constructive c, Constructive d, Constructive e, Constructive f, Constructive g) => Constructive (a, b, c, d, e, f, g) Source |
zeroList :: Constructive a => Int -> [a] Source
varList :: Constructive a => Int -> String -> [a] Source
randomList :: Constructive a => Int -> Rnd -> [a] Source
splitRndList :: Rnd -> [Rnd] Source
class ConstructiveSig a => FiniteSig a where Source
class Constructive a => Finite a where Source
Instances
| Finite () Source | |
| FiniteSig a => Finite (Signal a) Source | |
| (Finite a, Finite b) => Finite (a, b) Source | |
| (Finite a, Finite b, Finite c) => Finite (a, b, c) Source | |
| (Finite a, Finite b, Finite c, Finite d) => Finite (a, b, c, d) Source | |
| (Finite a, Finite b, Finite c, Finite d, Finite e) => Finite (a, b, c, d, e) Source | |
| (Finite a, Finite b, Finite c, Finite d, Finite e, Finite f) => Finite (a, b, c, d, e, f) Source | |
| (Finite a, Finite b, Finite c, Finite d, Finite e, Finite f, Finite g) => Finite (a, b, c, d, e, f, g) Source |
domainList :: Finite a => Int -> [[a]] Source
Methods
ifThenElse :: Signal Bool -> (a, a) -> a Source
Instances
| Choice () Source | |
| Choice Symbol Source | |
| Choice a => Choice [a] Source | |
| Choice (Signal a) Source | |
| Choice b => Choice (a -> b) Source | |
| (Choice a, Choice b) => Choice (a, b) Source | |
| (Choice a, Choice b, Choice c) => Choice (a, b, c) Source | |
| (Choice a, Choice b, Choice c, Choice d) => Choice (a, b, c, d) Source | |
| (Choice a, Choice b, Choice c, Choice d, Choice e) => Choice (a, b, c, d, e) Source | |
| (Choice a, Choice b, Choice c, Choice d, Choice e, Choice f) => Choice (a, b, c, d, e, f) Source | |
| (Choice a, Choice b, Choice c, Choice d, Choice e, Choice f, Choice g) => Choice (a, b, c, d, e, f, g) Source |
strongZipWith :: (a -> b -> c) -> [a] -> [b] -> [c] Source
lazyZipWith :: (a -> b -> c) -> [a] -> [b] -> [c] Source